==> llm4gpt-2023.4.20.17.47.53-py2.py3-none-any.whl: llm/chatllm.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : chatllm
# @Time         : 2023/4/20 15:46
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  :

from langchain.llms.base import LLM
from langchain.llms.utils import enforce_stop_tokens

# ME
from meutils.pipe import *
from llm.utils import cuda_empty_cache


class ChatLLM(LLM):
    """
    from llm.utils import llm_load

    model, tokenizer = llm_load("/Users/betterme/PycharmProjects/AI/CHAT_MODEL/chatglm")
    glm = ChatLLM()
    glm.chat_func = model.chat # partial(self.chat_func, **kwargs)
    """
    chat_func: Callable = None
    history = []
    max_turns = 3

    @property
    def _llm_type(self) -> str:
        return "ChatLLM"

    def _call(self, prompt: str, stop: Optional[List[str]] = None) -> str:
        cuda_empty_cache()  # todo: 减少调用次数

        response, _ = self.chat_func(query=prompt, history=self.history[-self.max_turns:])
        if stop:
            response = enforce_stop_tokens(response, stop)
        self.history += [(None, response)]
        return response  # todo: 增加流失输出

    def set_chat_kwargs(self, **kwargs):
        self.chat_func = partial(self.chat_func, **kwargs)


if __name__ == '__main__':
    from llm.utils import llm_load

    model, tokenizer = llm_load("/Users/betterme/PycharmProjects/AI/CHAT_MODEL/chatglm")
    glm = ChatLLM()
    glm.chat_func = partial(model.chat, tokenizer=tokenizer)
    glm.chat_func = partial(model.stream_chat, tokenizer=tokenizer)

==> llm4gpt-2023.4.20.18.20.32-py2.py3-none-any.whl: llm/chatllm.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : chatllm
# @Time         : 2023/4/20 15:46
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  :
import types
from langchain.llms.base import LLM
from langchain.llms.utils import enforce_stop_tokens

# ME
from meutils.pipe import *
from llm.utils import cuda_empty_cache


class ChatLLM(LLM):
    """
    from llm.utils import llm_load

    model, tokenizer = llm_load("/Users/betterme/PycharmProjects/AI/CHAT_MODEL/chatglm")
    glm = ChatLLM()
    glm.chat_func = model.chat # partial(self.chat_func, **kwargs)
    """
    chat_func: Callable = None
    history = []
    max_turns = 3

    @property
    def _llm_type(self) -> str:
        return "ChatLLM"

    def _call(self, prompt: str, stop: Optional[List[str]] = None) -> str:
        cuda_empty_cache()  # todo: 减少调用次数

        result = self.chat_func(query=prompt, history=self.history[-self.max_turns:])
        response = history = None
        if isinstance(result, types.GeneratorType):
            for response, history in tqdm(result):
                yield response, history
        else:
            response, history = result
        if stop:
            response = enforce_stop_tokens(response, stop)
        self.history = history
        return response

    def set_chat_kwargs(self, **kwargs):
        self.chat_func = partial(self.chat_func, **kwargs)


if __name__ == '__main__':
    from llm.utils import llm_load

    model, tokenizer = llm_load("/Users/betterme/PycharmProjects/AI/CHAT_MODEL/chatglm")
    glm = ChatLLM()
    glm.chat_func = partial(model.chat, tokenizer=tokenizer)
    glm.chat_func = partial(model.stream_chat, tokenizer=tokenizer)
